# masonite-api-pagination
Simple API pagination to Masonite API package with Orator

Have a look on [package wiki](https://github.com/rfschubert/masonite-api-pagination/wiki/Getting-Started) to see how to install and configure this package :)

This `Masonite` package was created to fast development of `API` endpoints with pagination. The concept is very simple.

Currently when you create one `Resource` file, you do something like this:
![img01](https://i.imgur.com/d2QOMEV.png)

Now, you can have one paginated endpoint, just changing a bit your file, to this:
![img02](https://i.imgur.com/6i7T0Lm.png)

And it's all done! You will get this response from your endpoint:
![img03](https://i.imgur.com/GtVl8Z5.png)

Have a look on [package wiki](https://github.com/rfschubert/masonite-api-pagination/wiki/Getting-Started) to have more informations about this awesome package :)
